=== modified file 'bzrlib/benchmarks/__init__.py'
--- bzrlib/benchmarks/__init__.py	2006-07-11 14:47:00 +0000
+++ bzrlib/benchmarks/__init__.py	2006-07-19 05:54:36 +0000
@@ -108,8 +108,10 @@
     testmod_names = [ \
                    'bzrlib.benchmarks.bench_add',
                    'bzrlib.benchmarks.bench_bench',
+                   'bzrlib.benchmarks.bench_bundle',
                    'bzrlib.benchmarks.bench_checkout',
                    'bzrlib.benchmarks.bench_commit',
+                   'bzrlib.benchmarks.bench_info',
                    'bzrlib.benchmarks.bench_inventory',
                    'bzrlib.benchmarks.bench_log',
                    'bzrlib.benchmarks.bench_osutils',

=== added file 'bzrlib/benchmarks/bench_bundle.py'
--- bzrlib/benchmarks/bench_bundle.py	1970-01-01 00:00:00 +0000
+++ bzrlib/benchmarks/bench_bundle.py	2006-07-19 05:54:36 +0000
@@ -0,0 +1,52 @@
+# Copyright (C) 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for bzr bundle performance."""
+
+
+from bzrlib.benchmarks import Benchmark
+
+
+class BundleBenchmark(Benchmark):
+    """
+    The bundle tests should (also) be done at a lower level with
+    direct call to the bzrlib."""
+    
+
+    def test_create_bundle_known_kernel_like_tree(self):
+        """
+        Create a bundle for a kernel sized tree with no ignored, unknowns,
+        or added and one commit.""" 
+        self.make_kernel_like_tree()
+        self.run_bzr('add')
+        self.run_bzr('commit', '-m', 'initial import')
+        self.time(self.run_bzr, 'bundle', '--revision', '..-1')
+
+    def test_create_bundle_many_commit_tree (self):
+        """
+        Create a bundle for a tree with many commits but no changes.""" 
+        self.make_many_commit_tree()
+        self.time(self.run_bzr, 'bundle', '--revision', '..-1')
+
+    def test_create_bundle_heavily_merged_tree(self):
+        """
+        Create a bundle for a heavily merged tree.""" 
+        self.make_heavily_merged_tree()
+        self.time(self.run_bzr, 'bundle', '--revision', '..-1')
+
+    #XXX tests for applying a bundle are still missing
+
+        
+ 

=== modified file 'bzrlib/benchmarks/bench_commit.py'
--- bzrlib/benchmarks/bench_commit.py	2006-05-24 08:34:28 +0000
+++ bzrlib/benchmarks/bench_commit.py	2006-07-19 04:29:08 +0000
@@ -34,3 +34,20 @@
         # on robertc's machine the first sample of this took 59750ms/77682ms
         # after initial call reduction                       53922ms/73918ms
         self.time(self.run_bzr, 'commit', '-m', 'first post')
+
+    def test_commit_single_file_in_kernel_like_tree(self):
+        """Commit of a new singel file to a kernel sized tree."""
+        # uncomment this to run the benchmark with the repository in memory
+        # not disk
+        # self.transport_server = MemoryServer
+        # self.make_kernel_like_tree(self.get_url())
+        self.make_kernel_like_tree()
+        self.run_bzr('add')
+        self.run_bzr('commit', '-m', 'first post')
+        filename = 'unique_file_name'
+        self.build_tree([filename])
+        self.run_bzr('add', filename)
+        self.time(self.run_bzr, 'commit', '-m', 'added singel file',
+                  filename)
+        
+        

=== added file 'bzrlib/benchmarks/bench_info.py'
--- bzrlib/benchmarks/bench_info.py	1970-01-01 00:00:00 +0000
+++ bzrlib/benchmarks/bench_info.py	2006-07-19 05:54:36 +0000
@@ -0,0 +1,39 @@
+# Copyright (C) 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as published by
+# the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for bzr info performance."""
+
+
+from bzrlib.benchmarks import Benchmark
+
+
+class InfoBenchmark(Benchmark):
+    """This is a stub. Use this benchmark with a network transport.
+    Currently "bzr info sftp://..." takes > 4 min"""
+
+    def test_no_ignored_unknown_kernel_like_tree(self):
+        """Info in a kernel sized tree with no ignored or unknowns. """
+        self.make_kernel_like_tree()
+        self.run_bzr('add')
+        self.time(self.run_bzr, 'info')
+
+    def test_no_changes_known_kernel_like_tree(self):
+        """Info in a kernel sized tree with no ignored, unknowns, or added.""" 
+        self.make_kernel_like_tree()
+        self.run_bzr('add')
+        self.run_bzr('commit', '-m', 'initial import')
+        self.time(self.run_bzr, 'info')
+
+ 

=== modified file 'bzrlib/benchmarks/bench_status.py'
--- bzrlib/benchmarks/bench_status.py	2006-05-27 03:11:07 +0000
+++ bzrlib/benchmarks/bench_status.py	2006-07-19 03:47:44 +0000
@@ -36,3 +36,12 @@
         self.run_bzr('add')
         self.run_bzr('commit', '-m', 'initial import')
         self.time(self.run_bzr, 'status')
+
+    def test_single_file_no_changes_known_kerenl_like_tree(self):
+        """Status in a kernel sized tree with no ignored, unknowns, or added
+        of a single file."""
+        #XXX depends on the filenames generated by make_kernel_like_tree
+        self.make_kernel_like_tree()
+        self.run_bzr('add')
+        self.run_bzr('commit', '-m', 'initial import')
+        self.time(self.run_bzr, 'status', '7/4/0/16')

